summaryrefslogtreecommitdiff
path: root/print-802_15_4.c
diff options
context:
space:
mode:
authorDenis Ovsienko <denis@ovsienko.info>2020-10-09 13:19:10 +0100
committerDenis Ovsienko <denis@ovsienko.info>2020-10-09 13:19:10 +0100
commitca71c847281b80fd6d9db36cd94a171858244fc6 (patch)
tree41d442286b61250682953daf49a6114e00cc247c /print-802_15_4.c
parente379a5690f6db797179fa5e0845ff731db2a7af7 (diff)
downloadtcpdump-ca71c847281b80fd6d9db36cd94a171858244fc6.tar.gz
Fix some spelling. [skip ci]
Diffstat (limited to 'print-802_15_4.c')
-rw-r--r--print-802_15_4.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/print-802_15_4.c b/print-802_15_4.c
index 717acec8..521c1cef 100644
--- a/print-802_15_4.c
+++ b/print-802_15_4.c
@@ -568,7 +568,7 @@ ieee802_15_4_print_superframe_specification(netdissect_options *ndo,
((ss >> 8) & 0xf));
if (CHECK_BIT(ss, 12)) { ND_PRINT(", BLE enabled"); }
if (CHECK_BIT(ss, 14)) { ND_PRINT(", PAN Coordinator"); }
- if (CHECK_BIT(ss, 15)) { ND_PRINT(", Assocation Permit"); }
+ if (CHECK_BIT(ss, 15)) { ND_PRINT(", Association Permit"); }
}
/*
@@ -787,7 +787,7 @@ ieee802_15_4_print_header_ie(netdissect_options *ndo,
}
}
if (ie_len < ptr + 8) {
- ND_PRINT(" [ERROR: Truncated before Time syncronization specification]");
+ ND_PRINT(" [ERROR: Truncated before Time synchronization specification]");
break;
}
ND_PRINT("Beacon timestamp = %" PRIu64 ", offset = %d",
@@ -1087,7 +1087,7 @@ ieee802_15_4_print_mlme_ie(netdissect_options *ndo,
}
break;
- case 0x1a: /* TSCH Syncronization IE. */
+ case 0x1a: /* TSCH Synchronization IE. */
if (sub_ie_len < 6) {
ND_PRINT("[ERROR: Length != 6]");
}
@@ -1212,7 +1212,7 @@ ieee802_15_4_print_mlme_ie(netdissect_options *ndo,
/* XXX Not implemented */
case 0x2c: /* TVWS Device Capabilities IE */
/* XXX Not implemented */
- case 0x2d: /* TVWS Device Catagory IE */
+ case 0x2d: /* TVWS Device Category IE */
/* XXX Not implemented */
case 0x2e: /* TVWS Device Identification IE */
/* XXX Not implemented */
@@ -1609,9 +1609,9 @@ ieee802_15_4_print_command_data(netdissect_options *ndo,
u_int i;
switch (command_id) {
- case 0x01: /* Assocation Request */
+ case 0x01: /* Association Request */
if (caplen != 1) {
- ND_PRINT("Invalid Assocation request command length");
+ ND_PRINT("Invalid Association request command length");
return -1;
} else {
uint8_t cap_info;
@@ -1632,9 +1632,9 @@ ieee802_15_4_print_command_data(netdissect_options *ndo,
return caplen;
}
break;
- case 0x02: /* Assocation Response */
+ case 0x02: /* Association Response */
if (caplen != 3) {
- ND_PRINT("Invalid Assocation response command length");
+ ND_PRINT("Invalid Association response command length");
return -1;
} else {
ND_PRINT("Short address = ");
@@ -1850,7 +1850,7 @@ ieee802_15_4_std_frames(netdissect_options *ndo,
if (CHECK_BIT(fc, 8)) {
/* Sequence number is suppressed. */
if (frame_version < 2) {
- /* Sequence number can only be supressed for frame
+ /* Sequence number can only be suppressed for frame
version 2 or higher, this is invalid frame. */
ND_PRINT("[ERROR: Sequence number suppressed on frames where version < 2]");
}